/***************************************************************************//**
 * @file
 * @brief I2C sensor select utility for BRD4166
 *******************************************************************************
 * # License
 * <b>Copyright 2020 Silicon Laboratories Inc. www.silabs.com</b>
 *******************************************************************************
 *
 * SPDX-License-Identifier: Zlib
 *
 * The licensor of this software is Silicon Laboratories Inc.
 *
 * This software is provided 'as-is', without any express or implied
 * warranty. In no event will the authors be held liable for any damages
 * arising from the use of this software.
 *
 * Permission is granted to anyone to use this software for any purpose,
 * including commercial applications, and to alter it and redistribute it
 * freely, subject to the following restrictions:
 *
 * 1. The origin of this software must not be misrepresented; you must not
 *    claim that you wrote the original software. If you use this software
 *    in a product, an acknowledgment in the product documentation would be
 *    appreciated but is not required.
 * 2. Altered source versions must be plainly marked as such, and must not be
 *    misrepresented as being the original software.
 * 3. This notice may not be removed or altered from any source distribution.
 *
 ******************************************************************************/

#ifndef SL_SENSOR_SELECT_H
#define SL_SENSOR_SELECT_H

/***********************************************************************************************//**
 * @addtogroup sensor_select
 * @{
 **************************************************************************************************/

#include "sl_i2cspm.h"
#include "sl_board_control.h"

/**************************************************************************//**
 * Select I2C peripheral for a given sensor.
 * @param[in] sensor Sensor to be selected.
 * @return Pointer to the I2C peripheral. NULL if sensor is not available.
 *****************************************************************************/
sl_i2cspm_t* sl_sensor_select(sl_board_sensor_t sensor);

/** @} (end addtogroup sensor_select) */
#endif // SL_SENSOR_SELECT_H
